function net = train_texture_dense(config, net, syn_mat, rHat_batch)

interval = floor(config.nIteration / 100);

SSD = zeros(config.nIteration, 1);
Energy = zeros(config.nIteration, 1);

net.filterSelected = reshape(single(1:config.numFilters), 1, config.numFilters);
net.selectedLambdas = zeros(1, config.numFilters, 'single');
net.numSelected = config.numFilters;
lambdas = zeros(1, config.numFilterTypes, 'single');

mean_img = gather(net.normalization.averageImage);

model_file = [config.working_folder, config.categoryName, '_iter_',...
    num2str(config.nIteration) ,'_model.mat'];
syn_file = [config.working_folder, config.categoryName, '_iter_',...
    num2str(config.nIteration) ,'_syn.mat'];

h = figure;

if ~exist(model_file, 'file') || config.forceLearn == true
    
    % response from model
    %% learning iteration: Generative boosting
    rHat_idx = 1;
    for iter = 1:config.nIteration
        disp( [ 'iteration: ' num2str(iter)]);
        
        %% MLE: Sampling and compute parameters lambda
        fprintf('Langevin dynamics sampling...\n');
        syn_mat = langevin_dynamics_fast(config, net, syn_mat); 
        fprintf('Langevin finished\n');
        
        
        rModel_selected = filter_response(net, syn_mat);
        rModel_selected = reshape(rModel_selected, [], config.numFilterTypes);
        rModel_selected = mean(rModel_selected);
        
        rHat_selected = rHat_batch{rHat_idx};
        rHat_selected = reshape(rHat_selected, [], config.numFilterTypes);
        rHat_selected = mean(rHat_selected);
        
        rHat_idx = mod(rHat_idx, numel(rHat_batch)) + 1;
        gradientF_selected = rHat_selected - rModel_selected;
        SSD(iter) = mean(abs(gradientF_selected));
        
        Energy(iter) = sum(rModel_selected .* lambdas);
        % second part
        Energy(iter) = Energy(iter) ...
            + sum(gather(reshape(syn_mat.^2, [], 1))) / 2 / config.refsig /config.refsig;
        
        % gradient ascent
        lambdas = lambdas + ...
            config.Gamma * gradientF_selected;
        
        net.selectedLambdas = ...
            reshape( repmat(lambdas, config.numFilters/config.numFilterTypes, 1), 1, [] );
        
        if mod(iter - 1, interval) == 0 || iter == config.nIteration
            % save samples
            draw_figures(config, syn_mat, iter, mean_img, SSD, Energy);
        end
    end
    save(model_file, 'net');
    save(syn_file, 'syn_mat');
    
    saveas(h, [config.working_folder, config.categoryName, '_iter_',...
        num2str(config.nIteration) ,'_error.fig']);
    saveas(h, [config.working_folder, config.categoryName, '_iter_',...
        num2str(config.nIteration) ,'_error.png'])
else
    load(model_file);
    load(syn_file);
end
end
